@@ -3,22 +3,26 @@
 kernel=$(uname -r)
 
 # defaults
-if [ "$kernel" == "2.6.28.10-power50" ]; then
-DRIVERPATH="/opt/wifi-pwner/compat-wireless/kp"
-else
-if [ "$kernel" == "2.6.28.10-power49+pre50" ]; then
-DRIVERPATH="/opt/wifi-pwner/compat-wireless/kp"
-else
+if [ "$kernel" == "2.6.28.10-power49" ]; then
 DRIVERPATH="/opt/wifi-pwner/compat-wireless/kp-old"
+else
+if [ "$kernel" == "2.6.28.10-power48" ]; then
+DRIVERPATH="/opt/wifi-pwner/compat-wireless/kp-old"
+else
+if [ "$kernel" == "2.6.28.10-power47" ]; then
+DRIVERPATH="/opt/wifi-pwner/compat-wireless/kp-old"
+else
+if [ "$kernel" == "2.6.28.10-power46-wl" ]; then
+DRIVERPATH="/opt/wifi-pwner/compat-wireless/kp-old"
+else
+if [ "$kernel" == "2.6.28.10-power40-wl" ]; then
+DRIVERPATH="/opt/wifi-pwner/compat-wireless/kp-old"
+else
+DRIVERPATH="/opt/wifi-pwner/compat-wireless/kp"
+fi
+fi
 fi
 fi
-FILEPATH="/opt/wifi-pwner/.default-mac"
-
-# Save mac address
-MACADDR="`ifconfig wlan0 | sed -n 's/.*HWaddr \([0-9A-Fa-f:]\+\).*/\1/p'`"
-
-if [ ! -f $FILEPATH/myMAC ]; then
-   echo $MACADDR > $FILEPATH/myMAC
 fi
 
 # Unload wifi modules
@@ -37,7 +41,6 @@ insmod $DRIVERPATH/cfg80211.ko
 insmod $DRIVERPATH/mac80211.ko
 insmod $DRIVERPATH/wl1251.ko
 insmod $DRIVERPATH/wl1251_spi.ko
-# Restore mac address
-ifconfig wlan0 down hw ether "$MACADDR"
 
 echo "Custom wl1251 module loaded (with injection) :)"
+sleep 1
