@@ -5,13 +5,13 @@ clear
 trap killing INT
 
 function echoMessage() {
-  /opt/wifi-pwner/tput setaf 2; /opt/wifi-pwner/tput setab 0;
+  /opt/wifi-pwner/tput setaf 2;
   echo $*
   /opt/wifi-pwner/tput sgr0
 }
 
 function killing() {
-  /opt/wifi-pwner/tput setaf 2; /opt/wifi-pwner/tput setab 0;
+  /opt/wifi-pwner/tput setaf 2;
   clear
   echoError "===========Exit properly using Menu!!!==========="
   sleep 1
@@ -21,19 +21,19 @@ function killing() {
 }
 
 function echoWarning() {
-  /opt/wifi-pwner/tput setaf 3; /opt/wifi-pwner/tput setab 0;
+  /opt/wifi-pwner/tput setaf 3;
   echo $*
   /opt/wifi-pwner/tput sgr0
 }
 
 function echoPrompt() {
-  /opt/wifi-pwner/tput setaf 4; /opt/wifi-pwner/tput setab 0;
+  /opt/wifi-pwner/tput setaf 4;
   echo $*
   /opt/wifi-pwner/tput sgr0
 }
 
 function echoError() {
-  /opt/wifi-pwner/tput setaf 1; /opt/wifi-pwner/tput setab 0;
+  /opt/wifi-pwner/tput setaf 1;
   echo $*
   /opt/wifi-pwner/tput sgr0
 }
@@ -75,7 +75,7 @@ fi
 }
 
 function airodump() {
-airodump-ng wlan0
+airodump-ng $WIFI
 }
 
 function setinterface() {
